=================
test_scraper_pypi
=================


.. image:: https://img.shields.io/pypi/v/test_scraper_pypi.svg
        :target: https://pypi.python.org/pypi/test_scraper_pypi

.. image:: https://img.shields.io/travis/kishore-s-15/test_scraper_pypi.svg
        :target: https://travis-ci.com/kishore-s-15/test_scraper_pypi

.. image:: https://readthedocs.org/projects/test-scraper-pypi/badge/?version=latest
        :target: https://test-scraper-pypi.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/kishore-s-15/test_scraper_pypi/shield.svg
     :target: https://pyup.io/repos/github/kishore-s-15/test_scraper_pypi/
     :alt: Updates



Testing scraper package as pip package


* Free software: MIT license
* Documentation: https://test-scraper-pypi.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
